package com.fs.app.controller;

import com.fs.app.annotation.Login;
import com.fs.common.core.domain.R;
import com.fs.live.domain.LiveData;
import com.fs.live.service.ILiveDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

import static com.fs.common.utils.SecurityUtils.getUserId;

@RestController
@RequestMapping("/app/live/liveData")
public class LiveDataController extends AppBaseController{

    @Autowired
    private ILiveDataService liveDataService;

    /**
     * 查询直播数据列表
     * */
    @Login
    @GetMapping("/list")
    public List<LiveData> list(LiveData liveData) {
        return liveDataService.selectLiveDataList(liveData);
    }

    /**
     * 查询直播数据详情
     * */
    @Login
    @GetMapping("/get/{liveId}")
    public R getLiveData(@PathVariable("liveId") Long liveId) {
        return R.ok().put("liveData", liveDataService.selectLiveDataByLiveId(liveId));
    }

    /**
     * 点赞
     * */
    @Login
    @GetMapping("/like/{liveId}")
    public R like(@PathVariable("liveId") Long liveId) {
        return R.ok(liveDataService.updateLikeByLiveId(liveId, Long.parseLong(getUserId())));
    }

    /**
     * 收藏
     * */
    @Login
    @GetMapping("/collect/{liveId}")
    public R collect(@PathVariable("liveId") Long liveId) {
        return R.ok(liveDataService.collect(liveId,  Long.parseLong(getUserId())));
    }

    /**
     * 关注
     * */
    @Login
    @GetMapping("/follow/{liveId}")
    public R follow(@PathVariable("liveId") Long liveId) {
        return R.ok(liveDataService.follow(liveId,  Long.parseLong(getUserId())));
    }

    /**
     * 收藏店铺/店铺商品
     * */
    @Login
    @GetMapping("/collectStore")
    public R collectStore(Long storeId, Long productId, Long liveId) {
        return R.ok(liveDataService.collectStore(storeId, productId, liveId,  Long.parseLong(getUserId())));
    }

    /**
     * 获取直播内数据
     * */
    @GetMapping("/getLiveViewData")
    public R getLiveViewData(Long liveId) {
        Map<String,Object> liveViewData =liveDataService.getLiveViewData(liveId);
        return R.ok(liveViewData);
    }


}
